Domain types for GA4GH refget Sequences v2.0.0 and Sequence Collections v1.0.0.
Structs
- Alias
- A naming authority alias for a sequence.
- Array
Element Comparison - Element-level comparison for a single attribute.
- Attribute
Comparison - Which attributes exist in each collection.
- Comparison
Result - The result of comparing two sequence collections.
- Error
Response - A structured JSON error response body.
- Refget
Service Details - Details specific to refget service-info.
- SeqCol
- A Level 2 sequence collection: the full attribute arrays.
- SeqCol
Level1 - Level 1 representation: per-attribute digests.
- Sequence
Metadata - Metadata for a single sequence, as returned by the
/sequence/{digest}/metadataendpoint. - Sequence
Service Info - Extended service-info for the refget Sequences API.
- Service
Info - GA4GH service-info response.
- Service
Type - GA4GH service type descriptor.
Enums
- Level
- The level of detail for a sequence collection response.
Functions
- compare
- Compare two sequence collections and produce a comparison result.